(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.simple_interactive_maps = {
    attach: function (context, settings) {

      const maps = once('map-load', '.interactive_map__wrapper', context);
      const aspectRatio = 0.68;

      maps.forEach(async function (map_wrapper) {
        const mapId = map_wrapper.getAttribute('data-map-id');

        const map = map_wrapper.querySelector('.map-placeholder');

        const mapData = settings.edMaps[mapId];

        let containerWidth = map.offsetWidth;
        let containerHeight = containerWidth * aspectRatio;
        let paper = Raphael(map, containerWidth, containerHeight);
        let paths = createPaths(paper, mapData);
        let text = createText(paper, mapData, { 'font-size': '11px', 'font-family': '"Rubik","Source Sans Pro Web",sans-serif', 'fill': '#e6e6e6' });

        applyInteractions(paper, mapData, paths, text);
        fitMap(paths, paper, containerWidth, containerHeight);

        const textElems = map.querySelectorAll('text');
        textElems.forEach(function (textElem) {
          textElem.style.pointerEvents = 'none';
        });

        $(window).resize(function () {
          containerWidth = map.offsetWidth;
          containerHeight = containerWidth * aspectRatio;
          fitMap(paths, paper, containerWidth, containerHeight);
        });
      });
    },
  };

  function createPaths(paper, mapData) {
    let paths = {};
    for (let state in mapData) {
      if (mapData[state]['hidden']) {
        continue;
      }
      let attr = {
        fill: mapData[state]['fill_color'],
        stroke: mapData[state]['stroke_color'],
        'stroke-width': 1,
        'stroke-linejoin': 'round',
      }
      paths[state] = paper.path(mapData[state].path).attr(attr);
    }
    return paths;
  }

  function createText(paper, mapData, attr) {
    let text = {};
    for (let state in mapData) {
      if (mapData[state]['hidden']) {
        continue;
      }
      text[state] = paper.text(mapData[state].text.x, mapData[state].text.y, mapData[state].text.text).attr(attr);
    }
    return text;
  }

  function applyInteractions(paper, mapData, paths, text) {
    for (let state in paths) {

      // Skip hidden states.
      if (mapData[state]['hidden']) {
        continue;
      }

      // Set up tooltip if there is content to be displayed.
      if (mapData[state]['tooltip']['processed'] != '') {
        new Opentip(paths[state][0], mapData[state]['tooltip']['processed']);
      }

      // Set up mouseover and mouseout color events.
      let onMouseOver = function (event) {
        paths[state].animate({ fill: mapData[state]['hover_color'] }, 500);
        text[state].attr({ 'font-weight': 'bold' });
      };

      let onMouseOut = function () {
        paths[state].animate({ fill: mapData[state]['fill_color'] }, 500);
        text[state].attr({ 'font-weight': 'normal' });
      };

      if (mapData[state]['action'] === 'url') {
        paths[state][0].style.cursor = 'pointer';
        text[state][0].style.cursor = 'pointer';
        // Open the url in a new tab
        paths[state][0].onclick = function () {
          window.open(mapData[state]['url'], '_blank');
        };
        text[state][0].onclick = function () {
          window.open(mapData[state]['url'], '_blank');
        }
      }

      if (mapData[state]['action'] === 'content') {
        paths[state][0].style.cursor = 'pointer';
        text[state][0].style.cursor = 'pointer';

        paths[state][0].onclick = function (event) {
          // Create a new Drupal dialog and set its content.
          let mapDetailDialog = Drupal.dialog('<div>' + mapData[state]['content']['processed'] + '</div>', {
            title: mapData[state]['label'],
            dialogClass: 'interactive-map-dialog',
            autoOpen: true,
            resizable: false,
            modal: true,
            width: 800,
            closeOnEscape: true,
          });
          // Open the dialog.
          mapDetailDialog.showModal();
        };

        text[state][0].onclick = function (event) {
          // Create a new Drupal dialog and set its content.
          let mapDetailDialog = Drupal.dialog('<div>' + mapData[state]['content']['processed'] + '</div>', {
            title: mapData[state]['label'],
            dialogClass: 'interactive-map-dialog',
            autoOpen: true,
            resizable: false,
            modal: true,
            width: 800,
            closeOnEscape: true,
          });
          // Open the dialog.
          mapDetailDialog.showModal();
        }
      }

      paths[state][0].style.cursor = 'pointer';
      text[state][0].style.cursor = 'pointer';
      paths[state][0].onmouseover = onMouseOver;
      text[state][0].onmouseover = onMouseOver;
      paths[state][0].onmouseout = onMouseOut;
      text[state][0].onmouseout = onMouseOut;
    }
  }

  function fitMap(paths, paper, width, height) {
    let st = paper.set();
    for (let statePath in paths) {
      st.push(paths[statePath]);
    }
    let bbox = st.getBBox();
    bbox = isFinite(bbox.width) && isFinite(bbox.height) ? bbox : { x: 0, y: 0, width: 1000, height: 900 };
    paper.setViewBox(bbox.x, bbox.y, bbox.width, bbox.height, true);
    paper.setSize(width, height);
  }

})(jQuery, Drupal, drupalSettings);

var mapData;

Opentip.styles.edmaps = {
  extends: 'standard',
  stem: true,
  fixed: true,
  tipJoint: 'bottom',
  showOn: 'mouseover',
  hideOn: 'mouseout',
  removeElementsOnHide: true,
  containInViewport: true,
};
Opentip.defaultStyle = 'edmaps';
