<?php

declare(strict_types=1);

namespace Drupal\simple_interactive_maps\Controller;

use Drupal\simple_interactive_maps\InteractiveMapInterface;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpKernel\Exception\HttpException;

/**
 * Download the region data as a CSV file.
 */
final class RegionExportController extends DataExportControllerBase {

  /**
   * Builds the response.
   */
  public function __invoke(InteractiveMapInterface $interactive_map = NULL): BinaryFileResponse {

    if (!($interactive_map instanceof InteractiveMapInterface)) {
      throw new HttpException(404, 'Interactive map not found');
    }

    $regions = $interactive_map->get('regions');

    $header = [
      'id',
      'label',
      'override_colors',
      'fill_color',
      'hover_color',
      'stroke_color',
      'override_tooltip',
      'tooltip_value',
      'tooltip_format',
      'override_action',
      'action',
      'url',
      'content_value',
      'content_format',
    ];

    $data = [];
    foreach ($regions as $region) {
      $data[] = [
        $region['id'],
        $region['label'],
        $region['override_colors'],
        $region['fill_color'],
        $region['hover_color'],
        $region['stroke_color'],
        $region['override_tooltip'],
        $region['tooltip']['value'],
        $region['tooltip']['format'],
        $region['override_action'],
        $region['action'],
        $region['url'],
        $region['content']['value'],
        $region['content']['format'],
      ];
    }

    $filename = $interactive_map->id() . '_regions.csv';

    return $this->exportCsvFile($data, $header, $filename);

  }

}
