<?php

declare(strict_types=1);

namespace Drupal\simple_interactive_maps\Controller;

use Drupal\simple_interactive_maps\InteractiveMapInterface;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpKernel\Exception\HttpException;

/**
 * Download the state data as a CSV file.
 */
final class StateExportController extends DataExportControllerBase {

  /**
   * Builds the response.
   */
  public function __invoke(InteractiveMapInterface $interactive_map = NULL): BinaryFileResponse {

    if (!($interactive_map instanceof InteractiveMapInterface)) {
      throw new HttpException(404, 'Interactive map not found');
    }

    $states = $interactive_map->get('details');

    $headers = [
      'id',
      'label',
      'hidden',
      'region',
      'fill_color',
      'hover_color',
      'stroke_color',
      'tooltip_value',
      'tooltip_format',
      'action',
      'url',
      'content_value',
      'content_format',
    ];

    $data = [];

    foreach ($states as $state) {
      $data[] = [
        $state['id'],
        $state['label'],
        (int) $state['hidden'],
        $state['region'],
        $state['fill_color'],
        $state['hover_color'],
        $state['stroke_color'],
        $state['tooltip']['value'],
        $state['tooltip']['format'],
        $state['action'],
        $state['url'],
        $state['content']['value'],
        $state['content']['format'],
      ];
      // Export state.
    }

    $fileName = $interactive_map->id() . '_states.csv';

    return $this->exportCsvFile($data, $headers, $fileName);

  }

}
