<?php

declare(strict_types=1);

namespace Drupal\simple_interactive_maps\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\simple_interactive_maps\InteractiveMapInterface;
use Symfony\Component\HttpKernel\Exception\HttpException;

/**
 * Region data upload form.
 */
final class RegionDataImportForm extends DataImportFormBase {

  /**
   * {@inheritDoc}
   */
  public function getFormId(): string {
    return 'simple_interactive_maps_region_data_import';
  }

  /**
   * {@inheritDoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, InteractiveMapInterface $interactive_map = NULL): array {

    if (!($interactive_map instanceof InteractiveMapInterface)) {
      throw new HttpException(404, 'Interactive map not found');
    }

    $form['map'] = [
      '#type' => 'value',
      '#value' => $interactive_map,
    ];

    $form['import_regions_file'] = [
      '#type' => 'file',
      '#title' => $this->t('Import regions'),
      '#element_validate' => ['::validateFileUpload'],
      '#required' => FALSE,
      '#description' => $this->t('Upload a CSV file with regions data.'),
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Send'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritDoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $fieldId = $this->getUploadFieldId();

    $file = $form_state->getValue($fieldId);
    $file_path = $file->getFileUri();
    $fh = fopen($file_path, 'rb');
    // Get headers and dispose of them.
    fgetcsv($fh);
    $regions = [];
    while ($row = fgetcsv($fh)) {
      $region = [
        'id' => $row[0],
        'label' => $row[1],
        'override_colors' => (bool) $row[2],
        'fill_color' => $row[3],
        'hover_color' => $row[4],
        'stroke_color' => $row[5],
        'override_tooltip' => (bool) $row[6],
        'tooltip' => [
          'value' => $row[7],
          'format' => $row[8],
        ],
        'override_action' => (bool) $row[9],
        'action' => $row[10],
        'url' => $row[11],
        'content' => [
          'value' => $row[12],
          'format' => $row[13],
        ],
      ];
      $regions[$row[0]] = $region;
    }
    fclose($fh);

    $interactiveMap = $form_state->getValue('map');
    $interactiveMap->set('regions', $regions);
    $interactiveMap->save();

    $this->messenger()->addStatus($this->t('Region data has been imported.'));

    $form_state->setRedirect('simple_interactive_maps.simple_interactive_maps_tools', ['interactive_map' => $interactiveMap->id()]);
  }

  /**
   * {@inheritDoc}
   */
  protected function getUploadFieldId(): string {
    return 'import_regions_file';
  }

}
