<?php

declare(strict_types=1);

namespace Drupal\simple_interactive_maps\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Simple Interactive Maps settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'simple_interactive_maps_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['simple_interactive_maps.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['default_fill_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Default fill color'),
      '#default_value' => $this->config('simple_interactive_maps.settings')
        ->get('default_fill_color'),
      '#description' => $this->t('The default fill color for map regions.'),
    ];

    $form['default_stroke_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Default stroke color'),
      '#default_value' => $this->config('simple_interactive_maps.settings')
        ->get('default_stroke_color'),
      '#description' => $this->t('The default stroke color for map regions.'),
    ];

    $form['default_hover_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Default hover color'),
      '#default_value' => $this->config('simple_interactive_maps.settings')
        ->get('default_hover_color'),
      '#description' => $this->t('The default hover color for map regions.'),
    ];

    $form['default_state_tooltip'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Default state tooltip'),
      '#default_value' => $this->config('simple_interactive_maps.settings')
        ->get('default_state_tooltip')['value'] ?? '',
      '#description' => $this->t('The default tooltip for map states.'),
      '#format' => $this->config('simple_interactive_maps.settings')
        ->get('default_state_tooltip')['format'] ?? 'full_html',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('simple_interactive_maps.settings')
      ->set('default_fill_color', $form_state->getValue('default_fill_color'))
      ->set('default_stroke_color', $form_state->getValue('default_stroke_color'))
      ->set('default_hover_color', $form_state->getValue('default_hover_color'))
      ->set('default_state_tooltip', $form_state->getValue('default_state_tooltip'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
