<?php

declare(strict_types=1);

namespace Drupal\simple_interactive_maps;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Url;
use Drupal\simple_interactive_maps\ClippableContent;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a listing of interactive maps.
 */
final class InteractiveMapListBuilder extends ConfigEntityListBuilder {

  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, protected ClippableContent $clippableContent) {
    parent::__construct($entity_type, $storage);
  }

  /**
   * {@inheritDoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    /** @var \Drupal\ed_helper\ClippableContent $clippableContent */
    $clippableContent = $container->get('simple_interactive_maps.clippable_content');

    return new static($entity_type, $container->get('entity_type.manager')
      ->getStorage('interactive_map'), $clippableContent);
  }

  /**
   * {@inheridDoc}
   */
  public function buildHeader(): array {
    $header['label'] = $this->t('Label');
    $header['id'] = $this->t('Machine name');
    $header['embed'] = $this->t('Embed code');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheridDoc}
   */
  public function buildRow(EntityInterface $entity): array {
    /** @var \Drupal\simple_interactive_maps\InteractiveMapInterface $entity */
    $row['label'] = $entity->label();
    $row['id'] = $entity->id();
    $row['embed'] = [
      'data' => $this->clippableContent->createClippableItem($entity->getEmbedCode(), 'simple_interactive_maps_embed_code'),
    ];
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritDoc}
   */
  public function getDefaultOperations(EntityInterface $entity): array {
    $operations = parent::getDefaultOperations($entity);

    $operations['details'] = [
      'title' => $this->t('Edit State Details'),
      'weight' => 10,
      'url' => Url::fromRoute('simple_interactive_maps.map_details_form', ['interactive_map' => $entity->id()]),
    ];

    $operations['regions'] = [
      'title' => $this->t('Edit Regions'),
      'weight' => 20,
      'url' => Url::fromRoute('simple_interactive_maps.map_regions_form', ['interactive_map' => $entity->id()]),
    ];

    $operations['preview'] = [
      'title' => $this->t('Preview'),
      'weight' => 30,
      'url' => Url::fromRoute('simple_interactive_maps.map_preview', ['interactive_map' => $entity->id()]),
    ];

    $operations['tools'] = [
      'title' => $this->t('Tools'),
      'weight' => 40,
      'url' => Url::fromRoute('simple_interactive_maps.simple_interactive_maps_tools', ['interactive_map' => $entity->id()]),
    ];

    return $operations;
  }

}
