<?php

namespace Drupal\simple_interactive_maps;

use Drupal\Core\Url;

trait RegionTableGeneratorTrait {

  public function generateRegionsTable(array $regions, InteractiveMapInterface $map): array {
    $table = [
      '#type' => 'table',
      '#header' => [
        $this->t('Region'),
        $this->t('Region ID'),
        $this->t('Override Colors'),
        $this->t('Override Action'),
        $this->t('Override Tooltip'),
        $this->t('Edit'),
      ],
      '#empty' => 'No regions created.',
      '#attributes' => [
        'id' => 'ed-regions-table',
      ],
    ];

    foreach ($regions as $id => $region) {
      $table[$id] = [
        '#attributes' => [
          'class' => ['ed-region-form-row'],
          'id' => ['row-region-' . strtolower($id)],
        ],
      ];

      $table[$id]['label'] = [
        '#type' => 'item',
        '#markup' => $region['label'],
      ];

      $table[$id]['id'] = [
        '#type' => 'item',
        '#markup' => $id,
      ];

      // Override Colors.
      $table[$id]['override_colors'] = [
        '#type' => 'item',
        '#markup' => $region['override_colors'] ? 'Yes' : 'No',
        '#attributes' => [
          'class' => ['ed-region-override-colors'],
        ],
      ];

      // Override Action.
      $table[$id]['override_action'] = [
        '#type' => 'item',
        '#markup' => $region['override_action'] ? 'Yes' : 'No',
        '#attributes' => [
          'class' => ['ed-region-override-action'],
        ],
      ];

      // Override Tooltip.
      $table[$id]['override_tooltip'] = [
        '#type' => 'item',
        '#markup' => $region['override_tooltip'] ? 'Yes' : 'No',
        '#attributes' => [
          'class' => ['ed-region-override-tooltip'],
        ],
      ];

      // Create drop button with edit/delete links.
      $table[$id]['actions'] = [
        '#type' => 'dropbutton',
        '#links' => [
          'edit' => [
            'title' => $this->t('Edit'),
            'url' => Url::fromRoute('simple_interactive_maps.map_region_edit_form', ['interactive_map' => $map->id(), 'region' => $id]),
            'attributes' => [
              'class' => ['use-ajax'],
              'data-dialog-type' => 'modal',
              'data-dialog-options' => \json_encode([
                'width' => 1000,
                'minHeight' => 600,
              ]),
            ],
          ],
          'delete' => [
            'title' => $this->t('Delete'),
            'url' => Url::fromRoute('simple_interactive_maps.region_delete_confirm', ['interactive_map' => $map->id(), 'region' => $id]),
            'attributes' => [
              'class' => ['use-ajax'],
              'data-dialog-type' => 'modal',
              'data-dialog-options' => \json_encode([
                'width' => 400,
                'minHeight' => 200,
              ]),
            ],
          ],
        ],
      ];

    }

    return $table;
  }

}
